__package_name__ = 'KGlobal'
__author__ = 'Kevin Russell'
__version__ = "1.0.15"
__description__ = '''File, encryption, SQL, XML, and etc...'''
__url__ = 'https://github.com/KLRussell/Python_KGlobal_Package'


if __name__ == '__main__':
    from runpy import run_module
    run_module('KGlobal_Core')
